# React App

Generated by `pd init react`.

## Structure

- `/public` serves static files e.g. images.
- `/src` contains the main application code.

```bash
|-- public/ # Static files
    |-- fonts/
        |-- Rosario-Regular.ttf
    |-- img/
        |-- pd.png
    |-- favicon.ico
    |-- index.html # HTML Entry point
    |-- logo192.png
    |-- logo512.png
    |-- manifest.json
    |-- robots.txt
|-- src/
    |-- apis/ (e.g. Backend APIs)
        |-- api.tsx
    |-- routes/ # Application routes (uses React Router)
        |-- Home.tsx
    |-- App.tsx # React Entry Point
    |-- Error.tsx
    |-- index.css
    |-- index.tsx
    |-- reportWebVitals.ts
|-- .gitignore
|-- package.json # React App dependencies
|-- README.md # This file
|-- tsconfig.json
```

## Install

In the root directory of the project, run:

```bash
npm install
```

## Run

In the root directory of the project, run:

```bash
npm start dev
```

Open [http://localhost:3000](http://localhost:3000) with your browser to see the result.

## Learn More

To learn React, check out the [React documentation](https://reactjs.org/).
